==> integration-tests-jobs-service-springboot-1.40.1-20230625.030328-1-sources.jar: org/acme/travels/TimersOnTaskProcess.java <==
package org.acme.travels;

import org.acme.travels.TimersOnTaskModel;
import org.kie.api.definition.process.Process;
import org.jbpm.ruleflow.core.RuleFlowProcessFactory;
import org.jbpm.process.core.datatype.impl.type.ObjectDataType;
import org.drools.core.util.KieFunctions;
import org.jbpm.process.core.datatype.impl.type.StringDataType;

@org.springframework.stereotype.Component("timersOnTask")
public class TimersOnTaskProcess extends org.kie.kogito.process.impl.AbstractProcess<org.acme.travels.TimersOnTaskModel> {

    @org.springframework.beans.factory.annotation.Autowired()
    public TimersOnTaskProcess(org.kie.kogito.app.Application app, org.kie.kogito.correlation.CorrelationService correlations) {
        super(app, java.util.Arrays.asList(), correlations);
        activate();
    }

    public TimersOnTaskProcess() {
    }

    @Override()
    public org.acme.travels.TimersOnTaskProcessInstance createInstance(org.acme.travels.TimersOnTaskModel value) {
        return new org.acme.travels.TimersOnTaskProcessInstance(this, value, this.createProcessRuntime());
    }

    public org.acme.travels.TimersOnTaskProcessInstance createInstance(java.lang.String businessKey, org.acme.travels.TimersOnTaskModel value) {
        return new org.acme.travels.TimersOnTaskProcessInstance(this, value, businessKey, this.createProcessRuntime());
    }

    public org.acme.travels.TimersOnTaskProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.correlation.CompositeCorrelation correlation, org.acme.travels.TimersOnTaskModel value) {
        return new org.acme.travels.TimersOnTaskProcessInstance(this, value, businessKey, this.createProcessRuntime(), correlation);
    }

    @Override()
    public org.acme.travels.TimersOnTaskModel createModel() {
        return new org.acme.travels.TimersOnTaskModel();
    }

    public org.acme.travels.TimersOnTaskProcessInstance createInstance(org.kie.kogito.Model value) {
        return this.createInstance((org.acme.travels.TimersOnTaskModel) value);
    }

    public org.acme.travels.TimersOnTaskProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.Model value) {
        return this.createInstance(businessKey, (org.acme.travels.TimersOnTaskModel) value);
    }

    public org.acme.travels.TimersOnTaskProcessInstance createInstance(org.kie.api.runtime.process.WorkflowProcessInstance wpi) {
        return new org.acme.travels.TimersOnTaskProcessInstance(this, this.createModel(), this.createProcessRuntime(), wpi);
    }

    public org.acme.travels.TimersOnTaskProcessInstance createReadOnlyInstance(org.kie.api.runtime.process.WorkflowProcessInstance wpi) {
        return new org.acme.travels.TimersOnTaskProcessInstance(this, this.createModel(), wpi);
    }

    protected org.kie.api.definition.process.Process process() {
        RuleFlowProcessFactory factory = RuleFlowProcessFactory.createProcess("timersOnTask", true);
        factory.variable("delay", org.jbpm.process.core.datatype.DataTypeResolver.fromClass(java.lang.String.class), null, "customTags", null);
        factory.name("timersOnTask");
        factory.packageName("org.acme.travels");
        factory.dynamic(false);
        factory.version("1.0");
        factory.type("BPMN");
        factory.visibility("Public");
        factory.metaData("TargetNamespace", "http://www.omg.org/bpmn20");
        org.jbpm.ruleflow.core.factory.HumanTaskNodeFactory<?> humanTaskNode1 = factory.humanTaskNode(1);
        humanTaskNode1.name("User Task 1");
        humanTaskNode1.workParameter("NodeName", "User Task 1");
        humanTaskNode1.workParameter("TaskName", "work");
        humanTaskNode1.workParameter("Skippable", "true");
        humanTaskNode1.mapDataInputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(), new org.jbpm.workflow.core.impl.DataDefinition("_DECEF7EE-8E20-4DC7-B9CC-829DF8F6ADBE_TaskNameInputX", "TaskName", "Object", null), java.util.Arrays.asList(new org.jbpm.workflow.core.node.Assignment(null, new org.jbpm.workflow.core.impl.DataDefinition("f2b8be77-a4aa-4eec-894c-eb1de073faf2", "EXPRESSION (work)", "java.lang.Object", "work"), new org.jbpm.workflow.core.impl.DataDefinition("_DECEF7EE-8E20-4DC7-B9CC-829DF8F6ADBE_TaskNameInputX", "TaskName", "Object", null))), null));
        humanTaskNode1.mapDataInputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(), new org.jbpm.workflow.core.impl.DataDefinition("_DECEF7EE-8E20-4DC7-B9CC-829DF8F6ADBE_SkippableInputX", "Skippable", "Object", null), java.util.Arrays.asList(new org.jbpm.workflow.core.node.Assignment(null, new org.jbpm.workflow.core.impl.DataDefinition("a7266a51-ee64-46b9-9947-783d31e21fea", "EXPRESSION (true)", "java.lang.Object", "true"), new org.jbpm.workflow.core.impl.DataDefinition("_DECEF7EE-8E20-4DC7-B9CC-829DF8F6ADBE_SkippableInputX", "Skippable", "Object", null))), null));
        humanTaskNode1.done();
        humanTaskNode1.metaData("UniqueId", "_DECEF7EE-8E20-4DC7-B9CC-829DF8F6ADBE");
        humanTaskNode1.metaData("elementname", "User Task 1");
        humanTaskNode1.metaData("x", 705);
        humanTaskNode1.metaData("width", 154);
        humanTaskNode1.metaData("y", 177);
        humanTaskNode1.metaData("height", 102);
        org.jbpm.ruleflow.core.factory.ActionNodeFactory<?> actionNode2 = factory.actionNode(2);
        actionNode2.name("Before Timer");
        actionNode2.action(kcontext -> {
            java.lang.String delay = (java.lang.String) kcontext.getVariable("delay");
            System.out.println("Before timer, waiting for task to be complete or expires in " + delay);
        });
        actionNode2.metaData("UniqueId", "_7144F58E-6B9F-4C06-98C3-1B9359686851");
        actionNode2.metaData("elementname", "Before Timer");
        actionNode2.metaData("NodeType", "ScriptTask");
        actionNode2.metaData("x", 446);
        actionNode2.metaData("width", 154);
        actionNode2.metaData("y", 177);
        actionNode2.metaData("height", 102);
        actionNode2.done();
        org.jbpm.ruleflow.core.factory.EndNodeFactory<?> endNode3 = factory.endNode(3);
        endNode3.name("End");
        endNode3.terminate(false);
        endNode3.metaData("UniqueId", "_C005CFDD-76A2-4483-8983-B517A55CEDB0");
        endNode3.metaData("elementname", "End");
        endNode3.metaData("x", 1120);
        endNode3.metaData("width", 56);
        endNode3.metaData("y", 379);
        endNode3.metaData("height", 56);
        endNode3.done();
        org.jbpm.ruleflow.core.factory.EndNodeFactory<?> endNode4 = factory.endNode(4);
        endNode4.name("End Event 2");
        endNode4.terminate(false);
        endNode4.metaData("UniqueId", "_E8083A8F-D9EA-4E8A-A363-D40906829E0C");
        endNode4.metaData("elementname", "End Event 2");
        endNode4.metaData("x", 1120);
        endNode4.metaData("width", 56);
        endNode4.metaData("y", 200);
        endNode4.metaData("height", 56);
        endNode4.done();
        org.jbpm.ruleflow.core.factory.ActionNodeFactory<?> actionNode5 = factory.actionNode(5);
        actionNode5.name("After Timer");
        actionNode5.action(kcontext -> {
            System.out.println("After timer");
        });
        actionNode5.metaData("UniqueId", "_6149ED0D-C469-4E71-8308-9DAB77EE1AD5");
        actionNode5.metaData("elementname", "After Timer");
        actionNode5.metaData("NodeType", "ScriptTask");
        actionNode5.metaData("x", 886);
        actionNode5.metaData("width", 154);
        actionNode5.metaData("y", 356);
        actionNode5.metaData("height", 102);
        actionNode5.done();
        org.jbpm.ruleflow.core.factory.StartNodeFactory<?> startNode6 = factory.startNode(6);
        startNode6.name("StartProcess");
        startNode6.interrupting(false);
        startNode6.metaData("UniqueId", "_7E2C104E-EE2D-4F32-A127-245FE3454ECA");
        startNode6.metaData("elementname", "StartProcess");
        startNode6.metaData("x", 310);
        startNode6.metaData("width", 56);
        startNode6.metaData("y", 200);
        startNode6.metaData("height", 56);
        startNode6.done();
        org.jbpm.ruleflow.core.factory.BoundaryEventNodeFactory<?> boundaryEventNode7 = factory.boundaryEventNode(7);
        boundaryEventNode7.name("BoundaryEvent");
        boundaryEventNode7.eventType("Timer-_DECEF7EE-8E20-4DC7-B9CC-829DF8F6ADBE-#{delay}-7");
        boundaryEventNode7.attachedTo("_DECEF7EE-8E20-4DC7-B9CC-829DF8F6ADBE");
        boundaryEventNode7.scope(null);
        boundaryEventNode7.metaData("UniqueId", "_8AC28C5C-0AF3-412F-ABBF-FAF966239155");
        boundaryEventNode7.metaData("EventType", "timer");
        boundaryEventNode7.metaData("x", 754);
        boundaryEventNode7.metaData("width", 56);
        boundaryEventNode7.metaData("y", 251);
        boundaryEventNode7.metaData("AttachedTo", "_DECEF7EE-8E20-4DC7-B9CC-829DF8F6ADBE");
        boundaryEventNode7.metaData("TimeDuration", "#{delay}");
        boundaryEventNode7.metaData("CancelActivity", true);
        boundaryEventNode7.metaData("height", 56);
        boundaryEventNode7.done();
        factory.connection(2, 1, "_C00B257C-741C-4541-9D18-4339383B158C");
        factory.connection(6, 2, "_8EC70170-62F5-48C3-BBA3-8F11E2DB771D");
        factory.connection(5, 3, "_DFE77F9F-6037-4009-B071-35B345C34ABE");
        factory.connection(1, 4, "_24FF8718-E460-4B66-8E17-3EC4BC46DE9F");
        factory.connection(7, 5, "_4E3102D2-08C6-4140-BF3A-A21C9B31959D");
        factory.validate();
        return factory.getProcess();
    }
}

==> integration-tests-jobs-service-springboot-3.0.0-20231201.044652-1-sources.jar: org/acme/travels/TimersOnTaskProcess.java <==
package org.acme.travels;

import org.acme.travels.TimersOnTaskModel;
import org.kie.api.definition.process.Process;
import org.jbpm.ruleflow.core.RuleFlowProcessFactory;
import org.jbpm.process.core.datatype.impl.type.ObjectDataType;
import org.drools.core.util.KieFunctions;
import org.jbpm.process.core.datatype.impl.type.StringDataType;

@org.springframework.stereotype.Component("timersOnTask")
public class TimersOnTaskProcess extends org.kie.kogito.process.impl.AbstractProcess<org.acme.travels.TimersOnTaskModel> {

    @org.springframework.beans.factory.annotation.Autowired()
    public TimersOnTaskProcess(org.kie.kogito.app.Application app, org.kie.kogito.correlation.CorrelationService correlations) {
        super(app, java.util.Arrays.asList(), correlations);
        activate();
    }

    public TimersOnTaskProcess() {
    }

    @Override()
    public org.acme.travels.TimersOnTaskProcessInstance createInstance(org.acme.travels.TimersOnTaskModel value) {
        return new org.acme.travels.TimersOnTaskProcessInstance(this, value, this.createProcessRuntime());
    }

    public org.acme.travels.TimersOnTaskProcessInstance createInstance(java.lang.String businessKey, org.acme.travels.TimersOnTaskModel value) {
        return new org.acme.travels.TimersOnTaskProcessInstance(this, value, businessKey, this.createProcessRuntime());
    }

    public org.acme.travels.TimersOnTaskProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.correlation.CompositeCorrelation correlation, org.acme.travels.TimersOnTaskModel value) {
        return new org.acme.travels.TimersOnTaskProcessInstance(this, value, businessKey, this.createProcessRuntime(), correlation);
    }

    @Override()
    public org.acme.travels.TimersOnTaskModel createModel() {
        return new org.acme.travels.TimersOnTaskModel();
    }

    public org.acme.travels.TimersOnTaskProcessInstance createInstance(org.kie.kogito.Model value) {
        return this.createInstance((org.acme.travels.TimersOnTaskModel) value);
    }

    public org.acme.travels.TimersOnTaskProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.Model value) {
        return this.createInstance(businessKey, (org.acme.travels.TimersOnTaskModel) value);
    }

    public org.acme.travels.TimersOnTaskProcessInstance createInstance(org.kie.api.runtime.process.WorkflowProcessInstance wpi) {
        return new org.acme.travels.TimersOnTaskProcessInstance(this, this.createModel(), this.createProcessRuntime(), wpi);
    }

    public org.acme.travels.TimersOnTaskProcessInstance createReadOnlyInstance(org.kie.api.runtime.process.WorkflowProcessInstance wpi) {
        return new org.acme.travels.TimersOnTaskProcessInstance(this, this.createModel(), wpi);
    }

    protected org.kie.api.definition.process.Process process() {
        RuleFlowProcessFactory factory = RuleFlowProcessFactory.createProcess("timersOnTask", true);
        factory.variable("delay", org.jbpm.process.core.datatype.DataTypeResolver.fromClass(java.lang.String.class), null, "customTags", null);
        factory.name("timersOnTask");
        factory.packageName("org.acme.travels");
        factory.dynamic(false);
        factory.version("1.0");
        factory.type("BPMN");
        factory.visibility("Public");
        factory.metaData("TargetNamespace", "http://www.omg.org/bpmn20");
        org.jbpm.ruleflow.core.factory.HumanTaskNodeFactory<?> humanTaskNode1 = factory.humanTaskNode(1);
        humanTaskNode1.name("User Task 1");
        humanTaskNode1.workParameter("NodeName", "User Task 1");
        humanTaskNode1.workParameter("TaskName", "work");
        humanTaskNode1.workParameter("Skippable", "true");
        humanTaskNode1.mapDataInputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(), new org.jbpm.workflow.core.impl.DataDefinition("_DECEF7EE-8E20-4DC7-B9CC-829DF8F6ADBE_TaskNameInputX", "TaskName", "Object", null), java.util.Arrays.asList(new org.jbpm.workflow.core.node.Assignment(null, new org.jbpm.workflow.core.impl.DataDefinition("f8f7ad05-e253-467a-9d12-f8d74be36a36", "EXPRESSION (work)", "java.lang.Object", "work"), new org.jbpm.workflow.core.impl.DataDefinition("_DECEF7EE-8E20-4DC7-B9CC-829DF8F6ADBE_TaskNameInputX", "TaskName", "Object", null))), null));
        humanTaskNode1.mapDataInputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(), new org.jbpm.workflow.core.impl.DataDefinition("_DECEF7EE-8E20-4DC7-B9CC-829DF8F6ADBE_SkippableInputX", "Skippable", "Object", null), java.util.Arrays.asList(new org.jbpm.workflow.core.node.Assignment(null, new org.jbpm.workflow.core.impl.DataDefinition("cfc7c7fa-9bb0-48aa-ac19-d0c77be57252", "EXPRESSION (true)", "java.lang.Object", "true"), new org.jbpm.workflow.core.impl.DataDefinition("_DECEF7EE-8E20-4DC7-B9CC-829DF8F6ADBE_SkippableInputX", "Skippable", "Object", null))), null));
        humanTaskNode1.done();
        humanTaskNode1.metaData("UniqueId", "_DECEF7EE-8E20-4DC7-B9CC-829DF8F6ADBE");
        humanTaskNode1.metaData("elementname", "User Task 1");
        humanTaskNode1.metaData("x", 705);
        humanTaskNode1.metaData("width", 154);
        humanTaskNode1.metaData("y", 177);
        humanTaskNode1.metaData("height", 102);
        org.jbpm.ruleflow.core.factory.ActionNodeFactory<?> actionNode2 = factory.actionNode(2);
        actionNode2.name("Before Timer");
        actionNode2.action(kcontext -> {
            java.lang.String delay = (java.lang.String) kcontext.getVariable("delay");
            System.out.println("Before timer, waiting for task to be complete or expires in " + delay);
        });
        actionNode2.metaData("UniqueId", "_7144F58E-6B9F-4C06-98C3-1B9359686851");
        actionNode2.metaData("elementname", "Before Timer");
        actionNode2.metaData("NodeType", "ScriptTask");
        actionNode2.metaData("x", 446);
        actionNode2.metaData("width", 154);
        actionNode2.metaData("y", 177);
        actionNode2.metaData("height", 102);
        actionNode2.done();
        org.jbpm.ruleflow.core.factory.EndNodeFactory<?> endNode3 = factory.endNode(3);
        endNode3.name("End");
        endNode3.terminate(false);
        endNode3.metaData("UniqueId", "_C005CFDD-76A2-4483-8983-B517A55CEDB0");
        endNode3.metaData("elementname", "End");
        endNode3.metaData("x", 1120);
        endNode3.metaData("width", 56);
        endNode3.metaData("y", 379);
        endNode3.metaData("height", 56);
        endNode3.done();
        org.jbpm.ruleflow.core.factory.EndNodeFactory<?> endNode4 = factory.endNode(4);
        endNode4.name("End Event 2");
        endNode4.terminate(false);
        endNode4.metaData("UniqueId", "_E8083A8F-D9EA-4E8A-A363-D40906829E0C");
        endNode4.metaData("elementname", "End Event 2");
        endNode4.metaData("x", 1120);
        endNode4.metaData("width", 56);
        endNode4.metaData("y", 200);
        endNode4.metaData("height", 56);
        endNode4.done();
        org.jbpm.ruleflow.core.factory.ActionNodeFactory<?> actionNode5 = factory.actionNode(5);
        actionNode5.name("After Timer");
        actionNode5.action(kcontext -> {
            System.out.println("After timer");
        });
        actionNode5.metaData("UniqueId", "_6149ED0D-C469-4E71-8308-9DAB77EE1AD5");
        actionNode5.metaData("elementname", "After Timer");
        actionNode5.metaData("NodeType", "ScriptTask");
        actionNode5.metaData("x", 886);
        actionNode5.metaData("width", 154);
        actionNode5.metaData("y", 356);
        actionNode5.metaData("height", 102);
        actionNode5.done();
        org.jbpm.ruleflow.core.factory.StartNodeFactory<?> startNode6 = factory.startNode(6);
        startNode6.name("StartProcess");
        startNode6.interrupting(false);
        startNode6.metaData("UniqueId", "_7E2C104E-EE2D-4F32-A127-245FE3454ECA");
        startNode6.metaData("elementname", "StartProcess");
        startNode6.metaData("x", 310);
        startNode6.metaData("width", 56);
        startNode6.metaData("y", 200);
        startNode6.metaData("height", 56);
        startNode6.done();
        org.jbpm.ruleflow.core.factory.BoundaryEventNodeFactory<?> boundaryEventNode7 = factory.boundaryEventNode(7);
        boundaryEventNode7.name("BoundaryEvent");
        boundaryEventNode7.eventType("Timer-_DECEF7EE-8E20-4DC7-B9CC-829DF8F6ADBE-#{delay}-7");
        boundaryEventNode7.attachedTo("_DECEF7EE-8E20-4DC7-B9CC-829DF8F6ADBE");
        boundaryEventNode7.scope(null);
        boundaryEventNode7.metaData("UniqueId", "_8AC28C5C-0AF3-412F-ABBF-FAF966239155");
        boundaryEventNode7.metaData("EventType", "timer");
        boundaryEventNode7.metaData("x", 754);
        boundaryEventNode7.metaData("width", 56);
        boundaryEventNode7.metaData("y", 251);
        boundaryEventNode7.metaData("AttachedTo", "_DECEF7EE-8E20-4DC7-B9CC-829DF8F6ADBE");
        boundaryEventNode7.metaData("TimeDuration", "#{delay}");
        boundaryEventNode7.metaData("CancelActivity", true);
        boundaryEventNode7.metaData("height", 56);
        boundaryEventNode7.done();
        factory.connection(2, 1, "_C00B257C-741C-4541-9D18-4339383B158C");
        factory.connection(6, 2, "_8EC70170-62F5-48C3-BBA3-8F11E2DB771D");
        factory.connection(5, 3, "_DFE77F9F-6037-4009-B071-35B345C34ABE");
        factory.connection(1, 4, "_24FF8718-E460-4B66-8E17-3EC4BC46DE9F");
        factory.connection(7, 5, "_4E3102D2-08C6-4140-BF3A-A21C9B31959D");
        factory.validate();
        return factory.getProcess();
    }
}
